# coding:utf-8

from config import MongoServer
import pymongo
from pymongo import ASCENDING, DESCENDING
from tornado.options import options
from sshtunnel import SSHTunnelForwarder

MongoCfg = {
    'authSource': 'proddb',
    'username': 'app',
    'password': 'Prod2app',
    'connecttimeoutms': 60 * 1000
}

# product DB
mongo_client = None
mongo_db = None

product = None


def init():
    if not MongoServer['active']:
        return

    global mongo_client
    global mongo_db

    global product

    if mongo_client is not None:
        return

    mongo_cfg = MongoServer[options.env]

    server = mongo_cfg['mongodb'].split(':')
    host = server[0]
    port = int(server[1]) if len(server) > 1 else 27017

    # 如果设置ssh登录，则通过ssh隧道登录（一般远程测试用）
    if 'ssh' in mongo_cfg and len(mongo_cfg['ssh']['pwd']) > 0:
        ssh_server = SSHTunnelForwarder(
            ssh_address_or_host=mongo_cfg['ssh']['address'],
            ssh_password=mongo_cfg['ssh']['pwd'],
            ssh_username=mongo_cfg['ssh']['usr'],
            remote_bind_address=(host, port))

        ssh_server.start()

        host = ssh_server.local_bind_host
        port = ssh_server.local_bind_port
    # END

    mongo_client = pymongo.MongoClient(host=host, port=port, **MongoCfg)
    mongo_db = mongo_client[MongoCfg['authSource']]

    # my collections
    product = mongo_db.product
    # END

    # 创建索引
    _product_index()

    # 初始化系统数据
    _init_data()


def start_session():
    return mongo_client.start_session()


def _product_index():
    """
    {
        "_id": ObjectId('5c729df2e155ac16da86a1d0'),
        "name": "live-pledge",                           # 产品标示名，英文、数字、"-"
        "catalog": ObjectId('5c710622e155ac0c39c8b66d'), # 所属分类节点ID
        "status": 30,                                    # 状态：-10:已删除；0:编辑中；10:待审；20:休眠中；30:已激活；
        "display": {
            "zh": "活期质押",
            "en": "Live Pledge"
        },
        "desc": {
            "zh": "灵活的质押和支取",
            "en": "Pledge and draw flexibly"
        },
        "icon": "http://your.com/icon/pledge.png",
        "the_pledged": {...},   # 被质押的东西
        "the_loaned": {...},    # 被贷出的东西
        "normal_rate": 1.5,   # 正常质押率，质押率：质押资产市值/贷款货币市值
        "warn_rate": 1.1,     # 禁戒质押率
        "bomb_rate": 1.05,    # 爆仓质押率
        "interest_rate": 0.0001 # 贷款利率（日利率）
        "created": 1551015331186,
        "updated": 1551015331186
    }
    """
    product.create_index('name')
    product.create_index([('catalog', ASCENDING), ("created", DESCENDING)])


def _init_data():
    pass
